RevanApiHealthEndpoint class

Constructors

RevanApiHealthEndpoint(RevanApiClient client)

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

check() → AsyncResult<HealthSummaryDto>
child<T extends RevanApiEndpoint>(EndpointFactory<T> factory) → T
inherited
details() → AsyncResult<HealthDetailsDto>
get<T>(String method, FromJson<T> fromJson, {Map<String, Object>? query, Set<int>? successStatusCodes}) → AsyncResult<T>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited